@@ -475,10 +475,15 @@ idle_notify_name_change (gpointer data)
   GailWindow *window;
   AtkObject *obj;
 
+  GDK_THREADS_ENTER ();
+
   window = GAIL_WINDOW (data);
   window->name_change_handler = 0;
   if (GTK_ACCESSIBLE (window)->widget == NULL)
-    return FALSE;
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   obj = ATK_OBJECT (window);
   if (obj->name == NULL)
@@ -489,6 +494,7 @@ idle_notify_name_change (gpointer data)
       g_object_notify (G_OBJECT (obj), "accessible-name");
     }
   g_signal_emit_by_name (obj, "visible_data_changed");
+  GDK_THREADS_LEAVE ();
   return FALSE;
 }
 
@@ -783,11 +789,15 @@ update_screen_info (gpointer data)
 {
   int screen_n = GPOINTER_TO_INT (data);
 
+  GDK_THREADS_ENTER ();
+
   gail_screens [screen_n].update_handler = 0;
   gail_screens [screen_n].update_stacked_windows = FALSE;
 
   get_stacked_windows (&gail_screens [screen_n]);
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -798,6 +808,8 @@ update_desktop_info (gpointer data)
   GailScreenInfo *info;
   int i;
 
+  GDK_THREADS_ENTER ();
+
   info = &gail_screens [screen_n];
   info->update_desktop_handler = 0;
 
@@ -810,6 +822,8 @@ update_desktop_info (gpointer data)
         }
     }
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
